==> cueplot-0.0.1-src.tar.gz: cueplot-0.0.1-src/gui/FitDialog.cpp <==
/*
 * Cueplot: a GUI front end to gnuplot
 * Copyright (C) 2007 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#include "FitDialog.h"
#include "FitBasicWidget.h"
#include "FitModifierWidget.h"
#include "FitOthersWidget.h"
#include "FitRangeWidget.h"
#include "Fit.h"

#include <QCoreApplication>
#include <QListWidget>
#include <QHBoxLayout>
#include <QPushButton>
#include <QSplitter>
#include <QStackedWidget>

FitDialog *FitDialog::instance_ = 0;

FitDialog &FitDialog::instance(QWidget *parent)
{
	if (!instance_) {
		instance_ = new FitDialog(parent);
	}
	return *instance_;
}

void FitDialog::destroyInstance()
{
	if (instance_) {
		delete instance_;
		instance_ = 0;
	}
}

FitDialog::FitDialog(QWidget *parent)
: QDialog(parent)
{
	setWindowTitle(tr("Fittings") + " - " 
			+ QCoreApplication::applicationName());

	fitBasicWidget = new FitBasicWidget;
	connect(fitBasicWidget, SIGNAL(optionChanged()),
			this, SLOT(setPushButton()));
	fitRangeWidget = new FitRangeWidget;
	fitModifierWidget = new FitModifierWidget;
	fitOthersWidget = new FitOthersWidget;

	pagesStackedWidget = new QStackedWidget;
	pagesStackedWidget->addWidget(fitBasicWidget);
	pagesStackedWidget->addWidget(fitRangeWidget);
	pagesStackedWidget->addWidget(fitModifierWidget);
	pagesStackedWidget->addWidget(fitOthersWidget);

	contentsListWidget = new QListWidget;
	for (int i = 0, j = pagesStackedWidget->count(); i < j; i++) {
		contentsListWidget->addItem(
				pagesStackedWidget->widget(i)->windowTitle());
	}
	contentsListWidget->setCurrentRow(0);
	connect(contentsListWidget,
			SIGNAL(currentItemChanged(QListWidgetItem *, QListWidgetItem *)),
			this, SLOT(changePage(QListWidgetItem *, QListWidgetItem *)));

	QSplitter *centerSplitter = new QSplitter;
	centerSplitter->addWidget(contentsListWidget);
	centerSplitter->addWidget(pagesStackedWidget);

	fitPushButton = new QPushButton;
	connect(fitPushButton, SIGNAL(clicked()), SLOT(fit()));
	fitPushButton->setText(tr("&Fit"));

	QPushButton *closeButton = new QPushButton;
	closeButton->setText(tr("&Close"));
	connect(closeButton, SIGNAL(clicked()), this, SLOT(accept()));

	// create layouts

	QHBoxLayout *buttonLayout = new QHBoxLayout;
	buttonLayout->addStretch();
	buttonLayout->addWidget(fitPushButton);
	buttonLayout->addWidget(closeButton);

	QVBoxLayout *mainLayout = new QVBoxLayout;
	mainLayout->addWidget(centerSplitter);
	mainLayout->addLayout(buttonLayout);

	setLayout(mainLayout);

	init();
}

void FitDialog::init()
{
	Fit fit;
	// insert current options
	fitBasicWidget->setFitFunction(fit.function());
	fitBasicWidget->setFitDataFile(fit.dataFile());
	fitBasicWidget->setFitParameterFile(fit.isParameterFile());
	fitBasicWidget->setFitParameterFile(fit.parameterFile());
	fitBasicWidget->setFitVariable(fit.variable());

	fitModifierWidget->setFitModifier(fit.dataFileModifier());

	fitOthersWidget->setFitLimit(fit.fitLimit());
	fitOthersWidget->setFitMaxIter(fit.fitMaxIter());

	setPushButton();
}

void FitDialog::fit()
{
	// get current options
	Fit fit;

	fit.setFunction(fitBasicWidget->fitFunction());
	fit.setDataFile(fitBasicWidget->fitDataFile());
	fit.setParameterFile(fitBasicWidget->isFitParameterFile());
	fit.setParameterFile(fitBasicWidget->fitParameterFile());
	fit.setVariable(fitBasicWidget->fitVariable());

	fit.setDataFileModifier(fitModifierWidget->fitModifier());

	fit.setFitLimit(fitOthersWidget->fitLimit());
	fit.setFitMaxIter(fitOthersWidget->fitMaxIter());

	emit executed(fit.command());
}

void FitDialog::setPushButton()
{
	fitPushButton->setEnabled(fitBasicWidget->canFit());
}

void FitDialog::changePage(QListWidgetItem *current,
		QListWidgetItem *previous)
{
	if (!current) {
		current = previous;
	}
	pagesStackedWidget->setCurrentIndex(contentsListWidget->row(current));
}

==> cueplot-0.0.2-src.tar.gz: cueplot-0.0.2-src/gui/FitDialog.cpp <==
/*
 * Cueplot: a GUI front end to gnuplot
 * Copyright (C) 2007 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#include "FitDialog.h"
#include "FitBasicWidget.h"
#include "FitModifierWidget.h"
#include "FitOthersWidget.h"
#include "FitRangeWidget.h"
#include "Fit.h"

#include <QCoreApplication>
#include <QListWidget>
#include <QHBoxLayout>
#include <QPushButton>
#include <QSplitter>
#include <QStackedWidget>

FitDialog *FitDialog::instance_ = 0;

FitDialog &FitDialog::instance(QWidget *parent)
{
	if (!instance_) {
		instance_ = new FitDialog(parent);
	}
	return *instance_;
}

void FitDialog::destroyInstance()
{
	if (instance_) {
		delete instance_;
		instance_ = 0;
	}
}

FitDialog::FitDialog(QWidget *parent)
: QDialog(parent)
{
	setWindowTitle(tr("Fittings") + " - " 
			+ QCoreApplication::applicationName());

	fitBasicWidget = new FitBasicWidget;
	connect(fitBasicWidget, SIGNAL(optionChanged()),
			this, SLOT(setPushButton()));
	fitRangeWidget = new FitRangeWidget;
	fitModifierWidget = new FitModifierWidget;
	fitOthersWidget = new FitOthersWidget;

	pagesStackedWidget = new QStackedWidget;
	pagesStackedWidget->addWidget(fitBasicWidget);
	pagesStackedWidget->addWidget(fitRangeWidget);
	pagesStackedWidget->addWidget(fitModifierWidget);
	pagesStackedWidget->addWidget(fitOthersWidget);

	contentsListWidget = new QListWidget;
	for (int i = 0, j = pagesStackedWidget->count(); i < j; i++) {
		QWidget *widget = pagesStackedWidget->widget(i);
		contentsListWidget->addItem(widget->windowTitle());
		contentsListWidget->item(i)->setWhatsThis(widget->whatsThis());
	}
	contentsListWidget->setCurrentRow(0);
	connect(contentsListWidget,
			SIGNAL(currentItemChanged(QListWidgetItem *, QListWidgetItem *)),
			this, SLOT(changePage(QListWidgetItem *, QListWidgetItem *)));

	QSplitter *centerSplitter = new QSplitter;
	centerSplitter->addWidget(contentsListWidget);
	centerSplitter->addWidget(pagesStackedWidget);

	fitPushButton = new QPushButton;
	connect(fitPushButton, SIGNAL(clicked()), SLOT(fit()));
	fitPushButton->setText(tr("&Fit"));

	QPushButton *closeButton = new QPushButton;
	closeButton->setText(tr("&Close"));
	connect(closeButton, SIGNAL(clicked()), this, SLOT(accept()));

	// create layouts

	QHBoxLayout *buttonLayout = new QHBoxLayout;
	buttonLayout->addStretch();
	buttonLayout->addWidget(fitPushButton);
	buttonLayout->addWidget(closeButton);

	QVBoxLayout *mainLayout = new QVBoxLayout;
	mainLayout->addWidget(centerSplitter);
	mainLayout->addLayout(buttonLayout);

	setLayout(mainLayout);

	init();
}

void FitDialog::init()
{
	Fit fit;
	// insert current options
	fitBasicWidget->setFitFunction(fit.function());
	fitBasicWidget->setFitDataFile(fit.dataFile());
	fitBasicWidget->setFitParameterFile(fit.isParameterFile());
	fitBasicWidget->setFitParameterFile(fit.parameterFile());
	fitBasicWidget->setFitVariable(fit.variable());

	fitModifierWidget->setFitModifier(fit.dataFileModifier());

	fitOthersWidget->setFitLimit(fit.fitLimit());
	fitOthersWidget->setFitMaxIter(fit.fitMaxIter());

	setPushButton();
}

void FitDialog::fit()
{
	// get current options
	Fit fit;

	fit.setFunction(fitBasicWidget->fitFunction());
	fit.setDataFile(fitBasicWidget->fitDataFile());
	fit.setParameterFile(fitBasicWidget->isFitParameterFile());
	fit.setParameterFile(fitBasicWidget->fitParameterFile());
	fit.setVariable(fitBasicWidget->fitVariable());

	fit.setDataFileModifier(fitModifierWidget->fitModifier());

	fit.setFitLimit(fitOthersWidget->fitLimit());
	fit.setFitMaxIter(fitOthersWidget->fitMaxIter());

	emit executed(fit.command());
}

void FitDialog::setPushButton()
{
	fitPushButton->setEnabled(fitBasicWidget->canFit());
}

void FitDialog::changePage(QListWidgetItem *current,
		QListWidgetItem *previous)
{
	if (!current) {
		current = previous;
	}
	pagesStackedWidget->setCurrentIndex(contentsListWidget->row(current));
}
